@@ -1,45 +1,42 @@
 //! Dumper components.
-use crate::*;
+use crate::{repr::Repr, *};
 use alloc::{
     format,
     string::{String, ToString},
     vec::Vec,
 };
 
-#[cfg(windows)]
-pub const NL: &str = "\r\n";
-#[cfg(not(windows))]
-pub const NL: &str = "\n";
+/// Newline symbol in common platforms.
+pub const NL: &str = if cfg!(windows) { "\r\n" } else { "\n" };
 
-/// The root type.
 #[derive(Eq, PartialEq)]
-pub enum Root {
+enum Root {
     Map,
     Array,
     Scalar,
 }
 
-/// The interface for dumping data structure.
-pub trait Dumper {
-    /// Generate indentation.
-    fn ind(level: usize) -> String {
-        "  ".repeat(level)
-    }
-
-    /// Recursive dump function.
-    fn dump(&self, level: usize, root: Root) -> String;
-}
-
-impl<R: repr::Repr> Dumper for NodeBase<R> {
+impl<R: Repr> NodeBase<R> {
     fn dump(&self, level: usize, root: Root) -> String {
         let mut doc = String::new();
-        if !self.anchor().is_empty() {
-            doc += &format!("&{} ", self.anchor());
+        let anchor = self.anchor();
+        if !anchor.is_empty() {
+            doc += &format!("&{} ", anchor);
         }
-        if !self.tag().is_empty() {
-            doc += &format!("!!{} ", self.tag());
+        let tag = self.tag();
+        if !tag.is_empty() {
+            doc += &if tag.starts_with(parser::DEFAULT_PREFIX) {
+                format!("!!{} ", tag)
+            } else if parser::Parser::<R>::new(tag.as_bytes())
+                .identifier()
+                .is_ok()
+            {
+                format!("!{} ", tag)
+            } else {
+                format!("!<{}> ", tag)
+            };
         }
-        let ind = Self::ind(level);
+        let ind = "  ".repeat(level);
         doc += &match self.yaml() {
             YamlBase::Null => "null".to_string(),
             YamlBase::Bool(b) => b.to_string(),
@@ -81,7 +78,7 @@ impl<R: repr::Repr> Dumper for NodeBase<R> {
                     }
                     let s = k.dump(level + 1, Root::Map);
                     if let YamlBase::Map(_) | YamlBase::Array(_) = k.yaml() {
-                        doc += &format!("?{}{}{}{}{}", Self::ind(level + 1), NL, s, NL, ind);
+                        doc += &format!("?{}{}{}{}{}", "  ".repeat(level + 1), NL, s, NL, ind);
                     } else {
                         doc += &s;
                     }
@@ -120,29 +117,30 @@ impl<R: repr::Repr> Dumper for NodeBase<R> {
 /// ```
 /// use yaml_peg::{dump, node, dumper::NL};
 ///
-/// let doc = dump(vec![
+/// let doc = dump(&[
 ///     node!({
 ///         "a" => "b",
 ///         "c" => "d",
 ///     }),
 /// ]);
-/// assert_eq!(doc, format!("a: b{0}c: d{0}", NL));
+/// let ans = "\
+/// a: b
+/// c: d
+/// ";
+/// assert_eq!(doc, ans.replace('\n', NL));
 /// ```
 ///
 /// When calling [`parse`] function then [`dump`] the string, the string can be reformatted.
-pub fn dump<I>(nodes: I) -> String
-where
-    I: IntoIterator,
-    I::Item: Dumper,
-{
+pub fn dump<R: Repr>(nodes: &[NodeBase<R>]) -> String {
     nodes
-        .into_iter()
+        .iter()
         .enumerate()
         .map(|(i, node)| {
+            let doc = node.dump(0, Root::Scalar) + NL;
             if i == 0 {
-                format!("{}{}", node.dump(0, Root::Scalar).trim_start(), NL)
+                doc
             } else {
-                format!("---{}{}{}", NL, node.dump(0, Root::Scalar).trim_start(), NL)
+                format!("---{}{}", NL, doc.trim_start())
             }
         })
         .collect()
